==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/ToolCommandEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolCommandDescriptionMetadata } from "./ToolCommandDescriptionMetadata";
import { ToolCommandEventArgsDescription } from "./ToolCommandEventArgsDescription";
/**
 * @hidden
 */
var ToolCommandEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ToolCommandEventArgsDescriptionMetadata, _super);
    function ToolCommandEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolCommandEventArgsDescriptionMetadata.b = function (a) {
        if (ToolCommandEventArgsDescriptionMetadata.a == null) {
            ToolCommandEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolCommandEventArgsDescriptionMetadata.c(ToolCommandEventArgsDescriptionMetadata.a);
        }
        if (a.g(ToolCommandEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(ToolCommandEventArgsDescriptionMetadata.a);
        ToolCommandDescriptionMetadata.d(a);
    };
    ToolCommandEventArgsDescriptionMetadata.c = function (a) {
        a.item("Command", "ExportedType:ToolCommand");
    };
    ToolCommandEventArgsDescriptionMetadata.d = function (a) {
        ToolCommandEventArgsDescriptionMetadata.b(a);
        a.u("ToolCommandEventArgs", function () { return new ToolCommandEventArgsDescription(); });
        a.t("ToolCommandEventArgs", ToolCommandEventArgsDescriptionMetadata.a);
    };
    ToolCommandEventArgsDescriptionMetadata.$t = markType(ToolCommandEventArgsDescriptionMetadata, 'ToolCommandEventArgsDescriptionMetadata');
    ToolCommandEventArgsDescriptionMetadata.a = null;
    return ToolCommandEventArgsDescriptionMetadata;
}(Base));
export { ToolCommandEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/ToolCommandEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolCommandDescriptionMetadata } from "./ToolCommandDescriptionMetadata";
import { ToolCommandEventArgsDescription } from "./ToolCommandEventArgsDescription";
/**
 * @hidden
 */
var ToolCommandEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ToolCommandEventArgsDescriptionMetadata, _super);
    function ToolCommandEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolCommandEventArgsDescriptionMetadata.b = function (a) {
        if (ToolCommandEventArgsDescriptionMetadata.a == null) {
            ToolCommandEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolCommandEventArgsDescriptionMetadata.c(ToolCommandEventArgsDescriptionMetadata.a);
        }
        if (a.j(ToolCommandEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(ToolCommandEventArgsDescriptionMetadata.a);
        ToolCommandDescriptionMetadata.d(a);
    };
    ToolCommandEventArgsDescriptionMetadata.c = function (a) {
        a.item("Command", "ExportedType:ToolCommand");
    };
    ToolCommandEventArgsDescriptionMetadata.d = function (a) {
        ToolCommandEventArgsDescriptionMetadata.b(a);
        a.aa("ToolCommandEventArgs", function () { return new ToolCommandEventArgsDescription(); });
        a.z("ToolCommandEventArgs", ToolCommandEventArgsDescriptionMetadata.a);
    };
    ToolCommandEventArgsDescriptionMetadata.$t = markType(ToolCommandEventArgsDescriptionMetadata, 'ToolCommandEventArgsDescriptionMetadata');
    ToolCommandEventArgsDescriptionMetadata.a = null;
    return ToolCommandEventArgsDescriptionMetadata;
}(Base));
export { ToolCommandEventArgsDescriptionMetadata };
